@@ -128,6 +128,8 @@ if(FALSE)##--- no longer used:
     j_off <- c(0L, cumsum(vapply(Tlst, ncol, 1L)))
 
     clss <- vapply(Tlst, class, "")
+    ## NB ("FIXME"): this requires the component classes to be *called*
+    ## -- "dgTMatrix" | "dnTMatrix" etc (and not just *extend* those)!
     typ <- substr(clss, 2, 2)
     knd <- substr(clss, 1, 1)
     sym <- typ == "s" # symmetric ones
@@ -309,7 +311,7 @@ setAs("ddiMatrix", "matrix", .ddi2mat)
 ## the non-ddi diagonalMatrix -- only "ldiMatrix" currently:
 setAs("diagonalMatrix", "matrix", .diag2mat)
 
-setMethod("as.vector", signature(x = "diagonalMatrix", mode="missing"),
+setMethod("as.vector", "diagonalMatrix",
 	  function(x, mode) {
 	      n <- x@Dim[1]
               mod.x <- mode(x@x)
@@ -317,7 +319,7 @@ setMethod("as.vector", signature(x = "diagonalMatrix", mode="missing"),
 	      if(n)
 		  r[1 + 0:(n - 1L) * (n + 1)] <-
 		      if(x@diag == "U") as1(mod=mod.x) else x@x
-	      r
+	      as.vector(r, mode)
 	  })
 
 setAs("diagonalMatrix", "generalMatrix", # prefer sparse:
