@@ -235,15 +235,44 @@ stopifnot(identical(x*D, (Dx <- D*x)),
 	  identical(Dx, local({d <- D; d@x <- d@x * x; d})))
 
 Lrg <- new("dgTMatrix", Dim = c(n,n))
+l0 <- as(as(Lrg, "lMatrix"), "lgCMatrix")
+d0 <- as(l0, "dgCMatrix")
+if(FALSE) { #_____________________ FIXME: Should use cholmod_l_*() everywhere (?)____
+## problem in  Csparse_to_dense :
+dl0 <- as(l0, "denseMatrix")
+dd0 <- as(d0, "denseMatrix")
+## currently, both give --- Error in asMethod(object) :
+##   Cholmod error 'problem too large' at file ../Core/cholmod_dense.c, line 105
+##--> And there it is 'Int_max' ==> ../src/CHOLMOD/Include/cholmod_internal.h
+## defines 'Int_max'  and does that dependinging of "mode", and
+## MM thinks we should use the "DLONG" mode now -- for 64-bit integers!
+##  ==> Then Int_max := SuiteSparse_long_max := LONG_MAX
+## (the latter from ../src/SuiteSparse_config/SuiteSparse_config.h )
+## ==> use cholmod_l_<foo> instead of cholmod_<foo> in *many places*
+
+## check they are ok
+stopifnot(identical(dim(dl0), c(n,n)), identical(dim(dd0), c(n,n)),
+          !any(dl0), all(dd0 == 0))
+rm(dl0, dd0)# too large to keep in memory and pass to checkMatrix()
+}
+
 diag(Lrg[2:9,1:8]) <- 1:8
 ## ==:  Lrg[2:9,1:8] <- `diag<-`(Lrg[2:9,1:8], 1:8)
 e1 <- try(Lrg == Lrg) # error message almost ok
-e2 <- try(!Lrg) # error message was "bad", now perfect
+(memGB <- Sys.memGB("MemFree")) # from test-tools-1.R
+##                                             __vv__
+e2 <- if(doExtras && is.finite(memGB) && memGB > 30) { # need around 18 GB
+          try(!Lrg) # now *works* on 64-bit machines with enough RAM
+          ## and immediately errors if LONG_VECTORs are not available
+      } # else NULL
+str(e2) # error, NULL or "worked"
 ina <- is.na(Lrg)# "all FALSE"
 stopifnot(grep("too large", e1) == 1,
-          grep("too large", e2) == 1,
+	  if(inherits(e2, "try-error")) grep("too large", e2) == 1
+	  else is.null(e2) || length(e2@x) == n^2,
           !any(ina))# <- gave warning previously
 stopifnot(suppressWarnings(any(Lrg)))# (double -> logical  warning)
+rm(e2)# too large...
 
 ## with dimnames:
 v <- c(a=1, b=2:3)
@@ -592,6 +621,12 @@ stopifnot(## something like the equivalent of  all(I. == Diagonal(3125)) :
           identical(as(I..,"diagonalMatrix"), I)
           )
 
+## printSpMatrix() ;  "suppressing (columns | rows) .." {and do it correctly!}
+IT3
+op <- options(width = 70, max.print = 1000)
+T125[-(1:50),] ## suppression ... is it correctly done?
+
+
 ###-- row- and column operations  {was ./rowcolOps.R }
 
 set.seed(321)
